@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import django_filters
 from rest_framework import viewsets
 from rest_framework import filters
@@ -24,7 +23,7 @@ class CommentViewSet(ListUpdateModelMixin, viewsets.ModelViewSet):
     queryset = Comment.objects.all()
     serializer_class = CommentSerializer
     filter_backends = (django_filters.rest_framework.DjangoFilterBackend,)
-    filter_class = CommentFilter
+    filterset_class = CommentFilter
 
 
 class CommentViewSetWithPermissions(CommentViewSet):
