@@ -1,6 +1,6 @@
 from django.test import override_settings
 
-from rest_framework_extensions.test import APITestCase
+from rest_framework.test import APITestCase
 
 from .models import (
     NestedRouterMixinUserModel as UserModel,
